@@ -42,6 +42,7 @@ class TestOrganization(TestModels):
             "type": "npm",
             "readOnly": "false",
             "testFrequency": "daily",
+            "isMonitored": "true",
             "totalDependencies": 438,
             "issueCountsBySeverity": {"low": 8, "high": 13, "medium": 15},
             "lastTestedDate": "2019-02-05T06:21:00.000Z",
@@ -265,6 +266,18 @@ class TestOrganization(TestModels):
             == organization.projects.get("6d5813be-7e6d-4ab8-80c2-1e3e2a454545").name
         )
 
+    def test_get_project_organization_has_client(
+        self, organization, project, requests_mock
+    ):
+        matcher = re.compile("project/6d5813be-7e6d-4ab8-80c2-1e3e2a454545$")
+        requests_mock.get(matcher, json=project)
+        assert (
+            organization.projects.get(
+                "6d5813be-7e6d-4ab8-80c2-1e3e2a454545"
+            ).organization.client
+            is not None
+        )
+
     def test_filter_projects_by_tag_missing_value(self, organization, requests_mock):
         with pytest.raises(SnykError):
             organization.projects.filter(tags=[{"key": "some-key"}])
@@ -309,6 +322,7 @@ class TestProject(TestModels):
             origin="cli",
             type="npm",
             readOnly="false",
+            isMonitored="true",
             testFrequency="daily",
             totalDependencies=438,
             issueCountsBySeverity={"low": 8, "high": 13, "medium": 15},
@@ -482,3 +496,54 @@ class TestProject(TestModels):
     def test_empty_licenses(self, project, organization_url, requests_mock):
         requests_mock.post("%s/licenses" % organization_url, json=[])
         assert [] == project.licenses.all()
+
+    def test_empty_license_severity(
+        self, organization, organization_url, requests_mock
+    ):
+        requests_mock.post(
+            "%s/licenses" % organization_url,
+            json={
+                "results": [
+                    {
+                        "id": "MIT",
+                        "dependencies": [
+                            {
+                                "id": "accepts@1.0.0",
+                                "name": "accepts",
+                                "version": "1.0.0",
+                                "packageManager": "npm",
+                            }
+                        ],
+                        "projects": [
+                            {
+                                "name": "atokeneduser/goof",
+                                "id": "6d5813be-7e6d-4ab8-80c2-1e3e2a454545",
+                            }
+                        ],
+                    }
+                ]
+            },
+        )
+        licenses = next(iter(organization.licenses.all()))
+        assert licenses.severity is None
+
+    def test_missing_package_version_in_dep_graph(
+        self, project, project_url, requests_mock
+    ):
+        requests_mock.get(
+            "%s/dep-graph" % project_url,
+            json={
+                "depGraph": {
+                    "pkgManager": {"name": "fake-package-manager"},
+                    "pkgs": [
+                        {
+                            "id": "fake-package@x.y.z",
+                            "info": {"name": "fake-package-name"},
+                        }
+                    ],
+                    "schemaVersion": "fake",
+                    "graph": {"rootNodeId": "fake", "nodes": []},
+                }
+            },
+        )
+        assert next(iter(project.dependency_graph.pkgs)).info.version is None
